==> nui_media-0.0.28.tar.gz: lib/ui/nui_video_player.dart <==
import 'package:better_player/better_player.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';
import 'package:nui_media/model/nui_media_file.dart';
import 'package:nui_media/nui_media_util.dart';

abstract class NUIVideoPlayerState<T extends StatefulWidget> extends State<T>{
  Widget getVideoPlayer();

  Widget adjustSize({bool adjustSize: false, @required NUIMediaFile mediaFile, double width, double height}) {
    if(adjustSize != true || mediaFile.hasSize() != true || (height == null && width == null)) {
      return getVideoPlayer();
    }
    else{
      final ratio = mediaFile.processHeightToWidthRatio();
      if(width != null && height != null){
        return Container(
          height: height,
          width: width,
          child: getVideoPlayer()
        );
      }
      else if(width != null){
        return Container(
          width: width,
          height: width * ratio,
          child: getVideoPlayer()
        );
      }
      else if(height != null){
        return Container(
          width: height / ratio,
          height: height,
          child: getVideoPlayer()
        );
      }
      return getVideoPlayer();
    }
  }

}

class NUIVideoPlayer extends StatefulWidget {
  NUIVideoPlayer({@required this.mediaFile, this.mute: false, this.boxFit, this.configuration, this.adjustSize: false, this.width, this.height, this.adjustOrientation: true});
  final NUIMediaFile mediaFile;
  final bool adjustSize;
  final double width;
  final double height;
  final bool mute;
  final BoxFit boxFit;
  final BetterPlayerConfiguration configuration;
  final bool adjustOrientation;

  @override
  _NUIVideoPlayerState createState() => _NUIVideoPlayerState();
}

class _NUIVideoPlayerState extends NUIVideoPlayerState<NUIVideoPlayer> {
  BetterPlayerController playerController;
  Orientation _orientationBeforeFullScreen;
  List<DeviceOrientation> _normalOrientations = [
    DeviceOrientation.portraitUp,
    DeviceOrientation.portraitDown,
    DeviceOrientation.landscapeLeft,
    DeviceOrientation.landscapeRight
  ];
  List<DeviceOrientation> _portraitOrientation = [
    DeviceOrientation.portraitUp,
    DeviceOrientation.portraitDown,
  ];
  List<DeviceOrientation> _landscapeOrientation = [
    DeviceOrientation.landscapeLeft,
    DeviceOrientation.landscapeRight
  ];

  @override
  void initState(){
    super.initState();
    playerController = NUIMediaUtil.getVideoController(widget.mediaFile, config: widget.configuration ?? BetterPlayerConfiguration(fit: widget.boxFit ?? BoxFit.fill));
    playerController.setVolume(widget.mute == true ? 0.0 : 1.0);

    if(widget.adjustOrientation == true) {
      playerController.addEventsListener((event) {
        ///On fullscreen event check current Orientation
        if (event.betterPlayerEventType ==
            BetterPlayerEventType.openFullscreen) {
          _orientationBeforeFullScreen = MediaQuery.of(context).orientation;
        }

        ///On fullscreen finish set DeviceOrientation based on saved Orientation
        if (event.betterPlayerEventType == BetterPlayerEventType.hideFullscreen) {
          if (_orientationBeforeFullScreen == Orientation.portrait) {
            SystemChrome.setPreferredOrientations(_portraitOrientation);
          }
          if (_orientationBeforeFullScreen == Orientation.landscape) {
            SystemChrome.setPreferredOrientations(_landscapeOrientation);
          }

          ///Once page correctly render in given Orientation, add normal
          ///orientations, so user can use both portrait and landscape.
          Future.delayed(Duration(milliseconds: 500), () {
            SystemChrome.setPreferredOrientations(_normalOrientations);
          });
        }
      });
    }
  }

  @override
  void dispose(){
    super.dispose();
    playerController?.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return adjustSize(mediaFile: widget.mediaFile, adjustSize: widget.adjustSize, width: widget.width, height: widget.height);
  }

  @override
  Widget getVideoPlayer() => BetterPlayer(controller: playerController);
}

==> nui_media-0.0.29.tar.gz: lib/ui/nui_video_player.dart <==
import 'package:better_player/better_player.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';
import 'package:nui_media/model/nui_media_file.dart';
import 'package:nui_media/nui_media_util.dart';

abstract class NUIVideoPlayerState<T extends StatefulWidget> extends State<T>{
  Widget getVideoPlayer();

  Widget adjustSize({bool adjustSize: false, @required NUIMediaFile mediaFile, double width, double height}) {
    if(adjustSize != true || mediaFile.hasSize() != true || (height == null && width == null)) {
      return getVideoPlayer();
    }
    else{
      final ratio = mediaFile.processHeightToWidthRatio();
      if(width != null && height != null){
        return Container(
          height: height,
          width: width,
          child: getVideoPlayer()
        );
      }
      else if(width != null){
        return Container(
          width: width,
          height: width * ratio,
          child: getVideoPlayer()
        );
      }
      else if(height != null){
        return Container(
          width: height / ratio,
          height: height,
          child: getVideoPlayer()
        );
      }
      return getVideoPlayer();
    }
  }

}

class NUIVideoPlayer extends StatefulWidget {
  NUIVideoPlayer({@required this.mediaFile, this.mute: false, this.boxFit, this.configuration, this.isPortrait: true, this.adjustSize: false, this.width, this.height, this.adjustOrientation: true});
  final NUIMediaFile mediaFile;
  final bool adjustSize;
  final double width;
  final double height;
  final bool mute;
  final BoxFit boxFit;
  final BetterPlayerConfiguration configuration;
  final bool adjustOrientation;
  final bool isPortrait;

  @override
  _NUIVideoPlayerState createState() => _NUIVideoPlayerState();
}

class _NUIVideoPlayerState extends NUIVideoPlayerState<NUIVideoPlayer> {
  BetterPlayerController playerController;
  Orientation _orientationBeforeFullScreen;
  List<DeviceOrientation> _normalOrientations = [
    DeviceOrientation.portraitUp,
    DeviceOrientation.portraitDown,
    DeviceOrientation.landscapeLeft,
    DeviceOrientation.landscapeRight
  ];
  List<DeviceOrientation> _portraitOrientation = [
    DeviceOrientation.portraitUp,
    DeviceOrientation.portraitDown,
  ];
  List<DeviceOrientation> _landscapeOrientation = [
    DeviceOrientation.landscapeLeft,
    DeviceOrientation.landscapeRight
  ];

  @override
  void initState(){
    super.initState();
    playerController = NUIMediaUtil.getVideoController(widget.mediaFile, config: widget.configuration ?? BetterPlayerConfiguration(fit: widget.boxFit ?? BoxFit.fill));
    playerController.setVolume(widget.mute == true ? 0.0 : 1.0);

    if(widget.adjustOrientation == true) {
      playerController.addEventsListener((event) {
        ///On fullscreen event check current Orientation
        if (event.betterPlayerEventType == BetterPlayerEventType.openFullscreen) {
          _orientationBeforeFullScreen = MediaQuery.of(context).orientation;
        }

        ///On fullscreen finish set DeviceOrientation based on saved Orientation
        if (event.betterPlayerEventType == BetterPlayerEventType.hideFullscreen) {
          if (_orientationBeforeFullScreen == Orientation.portrait) {
            SystemChrome.setPreferredOrientations(_portraitOrientation);
          }
          if (_orientationBeforeFullScreen == Orientation.landscape) {
            SystemChrome.setPreferredOrientations(_landscapeOrientation);
          }

          ///Once page correctly render in given Orientation, add normal
          ///orientations, so user can use both portrait and landscape.
          Future.delayed(Duration(milliseconds: 500), () {
            SystemChrome.setPreferredOrientations(widget.isPortrait == true ? _portraitOrientation : _normalOrientations);
          });
        }
      });
    }
  }

  @override
  void dispose(){
    super.dispose();
    playerController?.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return adjustSize(mediaFile: widget.mediaFile, adjustSize: widget.adjustSize, width: widget.width, height: widget.height);
  }

  @override
  Widget getVideoPlayer() => BetterPlayer(controller: playerController);
}
